summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorKohei Yoshida <kohei.yoshida@gmail.com>2012-10-18 16:28:20 +0200
committerKohei Yoshida <kohei.yoshida@gmail.com>2012-10-19 11:45:36 +0200
commit4b313fd5661ca5ac096e60d46691b1a9857877d9 (patch)
tree59ba989a24fe1d21562f9a3c8a465b124028c62a /svx
parentd47508e036fd30f410798f37d25039bb25528f60 (diff)
Merge SvListEntry and SvLBoxEntry into SvTreeListEntry.
Change-Id: I89cfc8c1288c00674fe64e791c149743d377d5ee
Diffstat (limited to 'svx')
-rw-r--r--svx/inc/svx/checklbx.hxx4
-rw-r--r--svx/inc/svx/ctredlin.hxx20
-rw-r--r--svx/inc/svx/fontlb.hxx8
-rw-r--r--svx/inc/svx/simptabl.hxx4
-rw-r--r--svx/source/dialog/checklbx.cxx14
-rw-r--r--svx/source/dialog/ctredlin.cxx20
-rw-r--r--svx/source/dialog/docrecovery.cxx14
-rw-r--r--svx/source/dialog/fontlb.cxx12
-rw-r--r--svx/source/dialog/simptabl.cxx8
-rw-r--r--svx/source/form/datanavi.cxx44
-rw-r--r--svx/source/form/filtnav.cxx82
-rw-r--r--svx/source/form/fmexch.cxx16
-rw-r--r--svx/source/form/navigatortree.cxx92
-rw-r--r--svx/source/form/tabwin.cxx4
-rw-r--r--svx/source/inc/datanavi.hxx10
-rw-r--r--svx/source/inc/docrecovery.hxx6
-rw-r--r--svx/source/inc/filtnav.hxx20
-rw-r--r--svx/source/inc/fmexch.hxx18
-rw-r--r--svx/source/inc/fmexpl.hxx30
-rw-r--r--svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx18
-rw-r--r--svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx4
-rw-r--r--svx/workben/msview/msview.cxx36
22 files changed, 242 insertions, 242 deletions
diff --git a/svx/inc/svx/checklbx.hxx b/svx/inc/svx/checklbx.hxx
index 1e977ddeff83..a2c62540fc8f 100644
--- a/svx/inc/svx/checklbx.hxx
+++ b/svx/inc/svx/checklbx.hxx
@@ -49,7 +49,7 @@ private:
using SvTreeListBox::InsertEntry;
// Avoid ambiguity with new InsertEntry:
- virtual SvLBoxEntry* InsertEntry( const XubString& rText, SvLBoxEntry* pParent,
+ virtual SvTreeListEntry* InsertEntry( const XubString& rText, SvTreeListEntry* pParent,
sal_Bool bChildrenOnDemand,
sal_uIntPtr nPos, void* pUserData,
SvLBoxButtonKind eButtonKind );
@@ -75,7 +75,7 @@ public:
sal_uInt16 GetCheckedEntryCount() const;
void CheckEntryPos ( sal_uInt16 nPos, sal_Bool bCheck = sal_True );
sal_Bool IsChecked ( sal_uInt16 nPos ) const;
- void ToggleCheckButton ( SvLBoxEntry* pEntry );
+ void ToggleCheckButton ( SvTreeListEntry* pEntry );
void* SetEntryData ( sal_uInt16 nPos, void* pNewData );
void* GetEntryData ( sal_uInt16 nPos ) const;
diff --git a/svx/inc/svx/ctredlin.hxx b/svx/inc/svx/ctredlin.hxx
index 64348d9bbfc1..2d7563b6d737 100644
--- a/svx/inc/svx/ctredlin.hxx
+++ b/svx/inc/svx/ctredlin.hxx
@@ -67,7 +67,7 @@ public:
void* pData;
};
-class SvxRedlinEntry : public SvLBoxEntry
+class SvxRedlinEntry : public SvTreeListEntry
{
public:
SvxRedlinEntry();
@@ -82,12 +82,12 @@ private:
Color aPrivColor;
public:
- SvLBoxColorString( SvLBoxEntry*,sal_uInt16 nFlags,const XubString& rStr,
+ SvLBoxColorString( SvTreeListEntry*,sal_uInt16 nFlags,const XubString& rStr,
const Color& rCol);
SvLBoxColorString();
~SvLBoxColorString();
- void Paint( const Point&, SvTreeListBox& rDev, sal_uInt16 nFlags,SvLBoxEntry* );
+ void Paint( const Point&, SvTreeListBox& rDev, sal_uInt16 nFlags,SvTreeListEntry* );
SvLBoxItem* Create() const;
};
@@ -115,8 +115,8 @@ private:
protected:
- virtual StringCompare ColCompare(SvLBoxEntry*,SvLBoxEntry*);
- virtual void InitEntry(SvLBoxEntry*,const XubString&,const Image&,const Image&,SvLBoxButtonKind);
+ virtual StringCompare ColCompare(SvTreeListEntry*,SvTreeListEntry*);
+ virtual void InitEntry(SvTreeListEntry*,const XubString&,const Image&,const Image&,SvLBoxButtonKind);
@@ -148,14 +148,14 @@ public:
sal_Bool IsValidComment(const String* pComment);
// }
- SvLBoxEntry* InsertEntry(const String& ,RedlinData *pUserData,
- SvLBoxEntry* pParent=NULL,sal_uIntPtr nPos=LIST_APPEND);
+ SvTreeListEntry* InsertEntry(const String& ,RedlinData *pUserData,
+ SvTreeListEntry* pParent=NULL,sal_uIntPtr nPos=LIST_APPEND);
- SvLBoxEntry* InsertEntry(const String& ,RedlinData *pUserData,const Color&,
- SvLBoxEntry* pParent=NULL,sal_uIntPtr nPos=LIST_APPEND);
+ SvTreeListEntry* InsertEntry(const String& ,RedlinData *pUserData,const Color&,
+ SvTreeListEntry* pParent=NULL,sal_uIntPtr nPos=LIST_APPEND);
- virtual SvLBoxEntry* CreateEntry() const;
+ virtual SvTreeListEntry* CreateEntry() const;
void SetColCompareHdl(const Link& rLink ) { aColCompareLink = rLink; }
const Link& GetColCompareHdl() const { return aColCompareLink; }
diff --git a/svx/inc/svx/fontlb.hxx b/svx/inc/svx/fontlb.hxx
index dad16fa35218..422e99cacd92 100644
--- a/svx/inc/svx/fontlb.hxx
+++ b/svx/inc/svx/fontlb.hxx
@@ -46,7 +46,7 @@ private:
public:
SvLBoxFontString();
SvLBoxFontString(
- SvLBoxEntry* pEntry,
+ SvTreeListEntry* pEntry,
sal_uInt16 nFlags,
const XubString& rString,
const Font& rFont,
@@ -57,14 +57,14 @@ public:
/** Creates a new empty list box item. */
virtual SvLBoxItem* Create() const;
- void InitViewData( SvTreeListBox*,SvLBoxEntry*,SvViewDataItem* );
+ void InitViewData( SvTreeListBox*,SvTreeListEntry*,SvViewDataItem* );
/** Paints this entry to the specified position, using the own font settings. */
void Paint(
const Point& rPos,
SvTreeListBox& rDev,
sal_uInt16 nFlags,
- SvLBoxEntry* pEntry );
+ SvTreeListEntry* pEntry );
};
@@ -103,7 +103,7 @@ protected:
/** Initializes a new SvLBoxFontString entry.
@descr Uses current value of maEntryFont to set the entry font (if mbUseFont is true). */
virtual void InitEntry(
- SvLBoxEntry* pEntry,
+ SvTreeListEntry* pEntry,
const XubString& rEntryText,
const Image& rCollImg,
const Image& rExpImg,
diff --git a/svx/inc/svx/simptabl.hxx b/svx/inc/svx/simptabl.hxx
index b12314f3da6e..89093d62f84a 100644
--- a/svx/inc/svx/simptabl.hxx
+++ b/svx/inc/svx/simptabl.hxx
@@ -96,7 +96,7 @@ protected:
virtual void Command( const CommandEvent& rCEvt );
- virtual StringCompare ColCompare(SvLBoxEntry*,SvLBoxEntry*);
+ virtual StringCompare ColCompare(SvTreeListEntry*,SvTreeListEntry*);
public:
SvxSimpleTable(SvxSimpleTableContainer& rParent, WinBits nBits = WB_BORDER);
@@ -139,7 +139,7 @@ public:
void SortByCol(sal_uInt16,sal_Bool bDir=sal_True);
sal_Bool GetSortDirection(){ return bSortDirection;}
sal_uInt16 GetSortedCol(){ return nSortCol;}
- SvLBoxItem* GetEntryAtPos( SvLBoxEntry* pEntry, sal_uInt16 nPos ) const;
+ SvLBoxItem* GetEntryAtPos( SvTreeListEntry* pEntry, sal_uInt16 nPos ) const;
CommandEvent GetCommandEvent()const;
inline sal_Bool IsFocusOnCellEnabled() const { return IsCellFocusEnabled(); }
diff --git a/svx/source/dialog/checklbx.cxx b/svx/source/dialog/checklbx.cxx
index a6b79d060870..92f46498a434 100644
--- a/svx/source/dialog/checklbx.cxx
+++ b/svx/source/dialog/checklbx.cxx
@@ -111,7 +111,7 @@ void SvxCheckListBox::SelectEntryPos( sal_uInt16 nPos, sal_Bool bSelect )
sal_uInt16 SvxCheckListBox::GetSelectEntryPos() const
{
- SvLBoxEntry* pEntry = GetCurEntry();
+ SvTreeListEntry* pEntry = GetCurEntry();
if ( pEntry )
return (sal_uInt16)GetModel()->GetAbsPos( pEntry );
@@ -122,7 +122,7 @@ sal_uInt16 SvxCheckListBox::GetSelectEntryPos() const
String SvxCheckListBox::GetText( sal_uInt16 nPos ) const
{
- SvLBoxEntry* pEntry = GetEntry( nPos );
+ SvTreeListEntry* pEntry = GetEntry( nPos );
if ( pEntry )
return GetEntryText( pEntry );
@@ -190,7 +190,7 @@ void* SvxCheckListBox::GetEntryData( sal_uInt16 nPos ) const
// -----------------------------------------------------------------------
-void SvxCheckListBox::ToggleCheckButton( SvLBoxEntry* pEntry )
+void SvxCheckListBox::ToggleCheckButton( SvTreeListEntry* pEntry )
{
if ( pEntry )
{
@@ -208,7 +208,7 @@ void SvxCheckListBox::MouseButtonDown( const MouseEvent& rMEvt )
if ( rMEvt.IsLeft() )
{
const Point aPnt = rMEvt.GetPosPixel();
- SvLBoxEntry* pEntry = GetEntry( aPnt );
+ SvTreeListEntry* pEntry = GetEntry( aPnt );
if ( pEntry )
{
@@ -228,7 +228,7 @@ void SvxCheckListBox::MouseButtonDown( const MouseEvent& rMEvt )
// check if the entry below the mouse changed during the base method call. This is possible if,
// for instance, a handler invoked by the base class tampers with the list entries.
- const SvLBoxEntry* pNewEntry = GetEntry( aPnt );
+ const SvTreeListEntry* pNewEntry = GetEntry( aPnt );
if ( pNewEntry != pEntry )
return;
@@ -249,7 +249,7 @@ void SvxCheckListBox::KeyInput( const KeyEvent& rKEvt )
if ( rKey.GetCode() == KEY_RETURN || rKey.GetCode() == KEY_SPACE )
{
- SvLBoxEntry* pEntry = GetCurEntry();
+ SvTreeListEntry* pEntry = GetCurEntry();
if ( pEntry )
{
@@ -265,7 +265,7 @@ void SvxCheckListBox::KeyInput( const KeyEvent& rKEvt )
// -----------------------------------------------------------------------
-SvLBoxEntry* SvxCheckListBox::InsertEntry( const XubString& rText, SvLBoxEntry* pParent, sal_Bool bChildrenOnDemand, sal_uIntPtr nPos, void* pUserData, SvLBoxButtonKind eButtonKind )
+SvTreeListEntry* SvxCheckListBox::InsertEntry( const XubString& rText, SvTreeListEntry* pParent, sal_Bool bChildrenOnDemand, sal_uIntPtr nPos, void* pUserData, SvLBoxButtonKind eButtonKind )
{
return SvTreeListBox::InsertEntry( rText, pParent, bChildrenOnDemand, nPos, pUserData, eButtonKind );
}
diff --git a/svx/source/dialog/ctredlin.cxx b/svx/source/dialog/ctredlin.cxx
index e1600455b8e2..99d3a086d0b4 100644
--- a/svx/source/dialog/ctredlin.cxx
+++ b/svx/source/dialog/ctredlin.cxx
@@ -77,7 +77,7 @@ RedlinData::~RedlinData()
//----------------------------------------------------------------------------
SvxRedlinEntry::SvxRedlinEntry()
- :SvLBoxEntry()
+ :SvTreeListEntry()
{
}
@@ -94,7 +94,7 @@ SvxRedlinEntry::~SvxRedlinEntry()
DBG_NAME(SvLBoxColorString);
-SvLBoxColorString::SvLBoxColorString( SvLBoxEntry*pEntry,sal_uInt16 nFlags,const XubString& rStr,
+SvLBoxColorString::SvLBoxColorString( SvTreeListEntry*pEntry,sal_uInt16 nFlags,const XubString& rStr,
const Color& rCol)
: SvLBoxString( pEntry, nFlags, rStr )
@@ -122,7 +122,7 @@ SvLBoxItem* SvLBoxColorString::Create() const
}
void SvLBoxColorString::Paint( const Point& rPos, SvTreeListBox& rDev,
- sal_uInt16 nFlags, SvLBoxEntry* pEntry )
+ sal_uInt16 nFlags, SvTreeListEntry* pEntry )
/* [Description]
Paint function of the SvLBoxColorString class. The relevant text with the
@@ -166,7 +166,7 @@ SvxRedlinTable::~SvxRedlinTable()
delete pCommentSearcher;
}
-StringCompare SvxRedlinTable::ColCompare(SvLBoxEntry* pLeft,SvLBoxEntry* pRight)
+StringCompare SvxRedlinTable::ColCompare(SvTreeListEntry* pLeft,SvTreeListEntry* pRight)
{
StringCompare eCompare=COMPARE_EQUAL;
@@ -387,8 +387,8 @@ sal_Bool SvxRedlinTable::IsValidComment(const String* pCommentStr)
return nTheFlag;
}
-SvLBoxEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserData,
- SvLBoxEntry* pParent,sal_uIntPtr nPos)
+SvTreeListEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserData,
+ SvTreeListEntry* pParent,sal_uIntPtr nPos)
{
aEntryColor=GetTextColor();
if(pUserData!=NULL)
@@ -414,8 +414,8 @@ SvLBoxEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserDat
}
-SvLBoxEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserData,const Color& aColor,
- SvLBoxEntry* pParent,sal_uIntPtr nPos)
+SvTreeListEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserData,const Color& aColor,
+ SvTreeListEntry* pParent,sal_uIntPtr nPos)
{
aEntryColor=aColor;
@@ -435,12 +435,12 @@ SvLBoxEntry* SvxRedlinTable::InsertEntry(const String& rStr,RedlinData *pUserDat
return SvxSimpleTable::InsertEntry( aFirstStr, pParent, sal_False, nPos, pUserData );
}
-SvLBoxEntry* SvxRedlinTable::CreateEntry() const
+SvTreeListEntry* SvxRedlinTable::CreateEntry() const
{
return new SvxRedlinEntry;
}
-void SvxRedlinTable::InitEntry( SvLBoxEntry* pEntry, const XubString& rStr,
+void SvxRedlinTable::InitEntry( SvTreeListEntry* pEntry, const XubString& rStr,
const Image& rColl, const Image& rExp, SvLBoxButtonKind eButtonKind )
{
SvLBoxButton* pButton;
diff --git a/svx/source/dialog/docrecovery.cxx b/svx/source/dialog/docrecovery.cxx
index 621c928dc6f0..aa68971d2ea4 100644
--- a/svx/source/dialog/docrecovery.cxx
+++ b/svx/source/dialog/docrecovery.cxx
@@ -883,7 +883,7 @@ void SaveProgressDialog::end()
}
//===============================================
-RecovDocListEntry::RecovDocListEntry( SvLBoxEntry* pEntry,
+RecovDocListEntry::RecovDocListEntry( SvTreeListEntry* pEntry,
sal_uInt16 nFlags,
const String& sText )
: SvLBoxString( pEntry, nFlags, sText )
@@ -894,7 +894,7 @@ RecovDocListEntry::RecovDocListEntry( SvLBoxEntry* pEntry,
void RecovDocListEntry::Paint(const Point& aPos ,
SvTreeListBox& aDevice,
sal_uInt16 /*nFlags */,
- SvLBoxEntry* pEntry )
+ SvTreeListEntry* pEntry )
{
const Image* pImg = 0;
const String* pTxt = 0;
@@ -970,7 +970,7 @@ RecovDocList::~RecovDocList()
}
//===============================================
-void RecovDocList::InitEntry( SvLBoxEntry* pEntry ,
+void RecovDocList::InitEntry( SvTreeListEntry* pEntry ,
const XubString& sText ,
const Image& aImage1,
const Image& aImage2,
@@ -1074,12 +1074,12 @@ RecoveryDialog::RecoveryDialog(Window* pParent,
String sName( rInfo.DisplayName );
sName += '\t';
sName += impl_getStatusString( rInfo );
- SvLBoxEntry* pEntry = m_aFileListLB.InsertEntry(sName, rInfo.StandardImage, rInfo.StandardImage);
+ SvTreeListEntry* pEntry = m_aFileListLB.InsertEntry(sName, rInfo.StandardImage, rInfo.StandardImage);
pEntry->SetUserData((void*)&rInfo);
}
// mark first item
- SvLBoxEntry* pFirst = m_aFileListLB.First();
+ SvTreeListEntry* pFirst = m_aFileListLB.First();
if (pFirst)
m_aFileListLB.SetCursor(pFirst, sal_True);
}
@@ -1332,7 +1332,7 @@ void RecoveryDialog::updateItems()
sal_uIntPtr i = 0;
for ( i=0; i<c; ++i )
{
- SvLBoxEntry* pEntry = m_aFileListLB.GetEntry(i);
+ SvTreeListEntry* pEntry = m_aFileListLB.GetEntry(i);
if ( !pEntry )
continue;
@@ -1356,7 +1356,7 @@ void RecoveryDialog::stepNext(TURLInfo* pItem)
sal_uIntPtr i = 0;
for (i=0; i<c; ++i)
{
- SvLBoxEntry* pEntry = m_aFileListLB.GetEntry(i);
+ SvTreeListEntry* pEntry = m_aFileListLB.GetEntry(i);
if (!pEntry)
continue;
diff --git a/svx/source/dialog/fontlb.cxx b/svx/source/dialog/fontlb.cxx
index 99388a6b106f..2f877b1b532a 100644
--- a/svx/source/dialog/fontlb.cxx
+++ b/svx/source/dialog/fontlb.cxx
@@ -40,7 +40,7 @@ SvLBoxFontString::SvLBoxFontString() :
}
SvLBoxFontString::SvLBoxFontString(
- SvLBoxEntry* pEntry, sal_uInt16 nFlags, const XubString& rString,
+ SvTreeListEntry* pEntry, sal_uInt16 nFlags, const XubString& rString,
const Font& rFont, const Color* pColor ) :
SvLBoxString( pEntry, nFlags, rString ),
maFont( rFont ),
@@ -64,7 +64,7 @@ SvLBoxItem* SvLBoxFontString::Create() const
return new SvLBoxFontString;
}
-void SvLBoxFontString::Paint( const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvLBoxEntry* pEntry )
+void SvLBoxFontString::Paint( const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvTreeListEntry* pEntry )
{
DBG_CHKTHIS( SvLBoxFontString, 0 );
Font aOldFont( rDev.GetFont() );
@@ -81,7 +81,7 @@ void SvLBoxFontString::Paint( const Point& rPos, SvTreeListBox& rDev, sal_uInt16
rDev.SetFont( aOldFont );
}
-void SvLBoxFontString::InitViewData( SvTreeListBox* pView, SvLBoxEntry* pEntry, SvViewDataItem* pViewData )
+void SvLBoxFontString::InitViewData( SvTreeListBox* pView, SvTreeListEntry* pEntry, SvViewDataItem* pViewData )
{
DBG_CHKTHIS( SvLBoxFontString, 0 );
Font aOldFont( pView->GetFont() );
@@ -113,7 +113,7 @@ void SvxFontListBox::InsertFontEntry( const String& rString, const Font& rFont,
void SvxFontListBox::SelectEntryPos( sal_uInt16 nPos, bool bSelect )
{
- SvLBoxEntry* pEntry = GetEntry( nPos );
+ SvTreeListEntry* pEntry = GetEntry( nPos );
if( pEntry )
{
Select( pEntry, bSelect );
@@ -128,7 +128,7 @@ void SvxFontListBox::SetNoSelection()
sal_uLong SvxFontListBox::GetSelectEntryPos() const
{
- SvLBoxEntry* pSvLBoxEntry = FirstSelected();
+ SvTreeListEntry* pSvLBoxEntry = FirstSelected();
return pSvLBoxEntry ? GetModel()->GetAbsPos( pSvLBoxEntry ) : LIST_APPEND;
}
@@ -138,7 +138,7 @@ XubString SvxFontListBox::GetSelectEntry() const
}
void SvxFontListBox::InitEntry(
- SvLBoxEntry* pEntry, const XubString& rEntryText,
+ SvTreeListEntry* pEntry, const XubString& rEntryText,
const Image& rCollImg, const Image& rExpImg,
SvLBoxButtonKind eButtonKind )
{
diff --git a/svx/source/dialog/simptabl.cxx b/svx/source/dialog/simptabl.cxx
index e76ad7ba8f18..bee99c2f23cc 100644
--- a/svx/source/dialog/simptabl.cxx
+++ b/svx/source/dialog/simptabl.cxx
@@ -420,7 +420,7 @@ IMPL_LINK( SvxSimpleTable, HeaderBarDblClick, HeaderBar*, pCtr)
return 0;
}
-SvLBoxItem* SvxSimpleTable::GetEntryAtPos( SvLBoxEntry* pEntry, sal_uInt16 nPos ) const
+SvLBoxItem* SvxSimpleTable::GetEntryAtPos( SvTreeListEntry* pEntry, sal_uInt16 nPos ) const
{
DBG_ASSERT(pEntry,"GetEntryText:Invalid Entry");
SvLBoxItem* pItem = NULL;
@@ -441,7 +441,7 @@ SvLBoxItem* SvxSimpleTable::GetEntryAtPos( SvLBoxEntry* pEntry, sal_uInt16 nPos
return pItem;
}
-StringCompare SvxSimpleTable::ColCompare(SvLBoxEntry* pLeft,SvLBoxEntry* pRight)
+StringCompare SvxSimpleTable::ColCompare(SvTreeListEntry* pLeft,SvTreeListEntry* pRight)
{
StringCompare eCompare=COMPARE_EQUAL;
@@ -471,8 +471,8 @@ StringCompare SvxSimpleTable::ColCompare(SvLBoxEntry* pLeft,SvLBoxEntry* pRight)
IMPL_LINK( SvxSimpleTable, CompareHdl, SvSortData*, pData)
{
- SvLBoxEntry* pLeft = (SvLBoxEntry*)(pData->pLeft );
- SvLBoxEntry* pRight = (SvLBoxEntry*)(pData->pRight );
+ SvTreeListEntry* pLeft = (SvTreeListEntry*)(pData->pLeft );
+ SvTreeListEntry* pRight = (SvTreeListEntry*)(pData->pRight );
return (long) ColCompare(pLeft,pRight);
}
diff --git a/svx/source/form/datanavi.cxx b/svx/source/form/datanavi.cxx
index d98787cc5974..c77b7f1d92ab 100644
--- a/svx/source/form/datanavi.cxx
+++ b/svx/source/form/datanavi.cxx
@@ -170,7 +170,7 @@ namespace svxform
}
void DataTreeListBox::StartDrag( sal_Int8 /*_nAction*/, const Point& /*_rPosPixel*/ )
{
- SvLBoxEntry* pSelected = FirstSelected();
+ SvTreeListEntry* pSelected = FirstSelected();
if ( !pSelected )
// no drag without an entry
return;
@@ -258,7 +258,7 @@ namespace svxform
m_pXFormsPage->DoMenuAction( _nSelectedPopupEntry );
}
- void DataTreeListBox::RemoveEntry( SvLBoxEntry* _pEntry )
+ void DataTreeListBox::RemoveEntry( SvTreeListEntry* _pEntry )
{
if ( _pEntry )
{
@@ -272,7 +272,7 @@ namespace svxform
sal_uIntPtr i, nCount = GetEntryCount();
for ( i = 0; i < nCount; ++i )
{
- SvLBoxEntry* pEntry = GetEntry(i);
+ SvTreeListEntry* pEntry = GetEntry(i);
if ( pEntry )
delete static_cast< ItemNode* >( pEntry->GetUserData() );
}
@@ -361,7 +361,7 @@ namespace svxform
}
//------------------------------------------------------------------------
void XFormsPage::AddChildren(
- SvLBoxEntry* _pParent, const ImageList& _rImgLst,
+ SvTreeListEntry* _pParent, const ImageList& _rImgLst,
const Reference< css::xml::dom::XNode >& _xNode )
{
DBG_ASSERT( m_xUIHelper.is(), "XFormsPage::AddChildren(): invalid UIHelper" );
@@ -397,7 +397,7 @@ namespace svxform
if ( !sName.isEmpty() )
{
ItemNode* pNode = new ItemNode( xChild );
- SvLBoxEntry* pEntry = m_aItemList.InsertEntry(
+ SvTreeListEntry* pEntry = m_aItemList.InsertEntry(
sName, aExpImg, aCollImg, _pParent, sal_False, LIST_APPEND, pNode );
if ( xChild->hasAttributes() )
{
@@ -456,7 +456,7 @@ namespace svxform
Reference< XSet > xSubmissions( xModel->getSubmissions(), UNO_QUERY );
xSubmissions->insert( makeAny( xNewSubmission ) );
Reference< XPropertySet > xNewPropSet( xNewSubmission, UNO_QUERY );
- SvLBoxEntry* pEntry = AddEntry( xNewPropSet );
+ SvTreeListEntry* pEntry = AddEntry( xNewPropSet );
m_aItemList.Select( pEntry, sal_True );
bIsDocModified = true;
}
@@ -469,7 +469,7 @@ namespace svxform
else
{
DataItemType eType = DITElement;
- SvLBoxEntry* pEntry = m_aItemList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aItemList.FirstSelected();
ItemNode* pNode = NULL;
Reference< css::xml::dom::XNode > xParentNode;
Reference< XPropertySet > xNewBinding;
@@ -582,7 +582,7 @@ namespace svxform
{
if ( RET_OK == nReturn )
{
- SvLBoxEntry* pNewEntry = AddEntry( pNode, bIsElement );
+ SvTreeListEntry* pNewEntry = AddEntry( pNode, bIsElement );
m_aItemList.MakeVisible( pNewEntry );
m_aItemList.Select( pNewEntry, sal_True );
bIsDocModified = true;
@@ -609,7 +609,7 @@ namespace svxform
{
if ( RET_OK == nReturn )
{
- SvLBoxEntry* pNewEntry = AddEntry( xNewBinding );
+ SvTreeListEntry* pNewEntry = AddEntry( xNewBinding );
m_aItemList.Select( pNewEntry, sal_True );
bIsDocModified = true;
}
@@ -634,7 +634,7 @@ namespace svxform
case TBI_ITEM_EDIT:
{
bHandled = true;
- SvLBoxEntry* pEntry = m_aItemList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aItemList.FirstSelected();
if ( pEntry )
{
if ( DGTSubmission == m_eGroup && m_aItemList.GetParent( pEntry ) )
@@ -759,9 +759,9 @@ namespace svxform
}
//------------------------------------------------------------------------
- SvLBoxEntry* XFormsPage::AddEntry( ItemNode* _pNewNode, bool _bIsElement )
+ SvTreeListEntry* XFormsPage::AddEntry( ItemNode* _pNewNode, bool _bIsElement )
{
- SvLBoxEntry* pParent = m_aItemList.FirstSelected();
+ SvTreeListEntry* pParent = m_aItemList.FirstSelected();
const ImageList& rImageList = m_pNaviWin->GetItemImageList();
sal_uInt16 nImageID = ( _bIsElement ) ? IID_ELEMENT : IID_ATTRIBUTE;
Image aImage = rImageList.GetImage( nImageID );
@@ -965,9 +965,9 @@ namespace svxform
};
//------------------------------------------------------------------------
- SvLBoxEntry* XFormsPage::AddEntry( const Reference< XPropertySet >& _rEntry )
+ SvTreeListEntry* XFormsPage::AddEntry( const Reference< XPropertySet >& _rEntry )
{
- SvLBoxEntry* pEntry = NULL;
+ SvTreeListEntry* pEntry = NULL;
const ImageList& rImageList = m_pNaviWin->GetItemImageList();
Image aImage = rImageList.GetImage( IID_ELEMENT );
@@ -1038,7 +1038,7 @@ namespace svxform
//------------------------------------------------------------------------
void XFormsPage::EditEntry( const Reference< XPropertySet >& _rEntry )
{
- SvLBoxEntry* pEntry = NULL;
+ SvTreeListEntry* pEntry = NULL;
rtl::OUString sTemp;
if ( DGTSubmission == m_eGroup )
@@ -1062,7 +1062,7 @@ namespace svxform
String sEntry = SVX_RESSTR( RID_STR_DATANAV_SUBM_BIND );
sEntry += String( sTemp );
sal_uIntPtr nPos = 0;
- SvLBoxEntry* pChild = m_aItemList.GetEntry( pEntry, nPos++ );
+ SvTreeListEntry* pChild = m_aItemList.GetEntry( pEntry, nPos++ );
m_aItemList.SetEntryText( pChild, sEntry );
_rEntry->getPropertyValue( PN_SUBMISSION_REF ) >>= sTemp;
sEntry = SVX_RESSTR( RID_STR_DATANAV_SUBM_REF );
@@ -1096,7 +1096,7 @@ namespace svxform
bool XFormsPage::RemoveEntry()
{
bool bRet = false;
- SvLBoxEntry* pEntry = m_aItemList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aItemList.FirstSelected();
if ( pEntry &&
( DGTInstance != m_eGroup || m_aItemList.GetParent( pEntry ) ) )
{
@@ -1121,7 +1121,7 @@ namespace svxform
aQBox.SetMessText( sMessText );
if ( aQBox.Execute() == RET_YES )
{
- SvLBoxEntry* pParent = m_aItemList.GetParent( pEntry );
+ SvTreeListEntry* pParent = m_aItemList.GetParent( pEntry );
DBG_ASSERT( pParent, "XFormsPage::RemoveEntry(): no parent entry" );
ItemNode* pParentNode = static_cast< ItemNode* >( pParent->GetUserData() );
DBG_ASSERT( pParentNode && pParentNode->m_xNode.is(), "XFormsPage::RemoveEntry(): no parent XNode" );
@@ -1427,7 +1427,7 @@ namespace svxform
sal_Bool bEnableEdit = sal_False;
sal_Bool bEnableRemove = sal_False;
- SvLBoxEntry* pEntry = m_aItemList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aItemList.FirstSelected();
if ( pEntry )
{
bEnableAdd = sal_True;
@@ -3211,7 +3211,7 @@ namespace svxform
else if ( &m_aEditNamespaceBtn == pBtn )
{
ManageNamespaceDialog aDlg( this, m_pConditionDlg, true );
- SvLBoxEntry* pEntry = m_aNamespacesList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aNamespacesList.FirstSelected();
DBG_ASSERT( pEntry, "NamespaceItemDialog::ClickHdl(): no entry" );
String sPrefix( m_aNamespacesList.GetEntryText( pEntry, 0 ) );
aDlg.SetNamespace(
@@ -3229,7 +3229,7 @@ namespace svxform
}
else if ( &m_aDeleteNamespaceBtn == pBtn )
{
- SvLBoxEntry* pEntry = m_aNamespacesList.FirstSelected();
+ SvTreeListEntry* pEntry = m_aNamespacesList.FirstSelected();
DBG_ASSERT( pEntry, "NamespaceItemDialog::ClickHdl(): no entry" );
::rtl::OUString sPrefix( m_aNamespacesList.GetEntryText( pEntry, 0 ) );
m_aRemovedList.push_back( sPrefix );
@@ -3257,7 +3257,7 @@ namespace svxform
sal_Int32 nEntryCount = m_aNamespacesList.GetEntryCount();
for( i = 0; i < nEntryCount; ++i )
{
- SvLBoxEntry* pEntry = m_aNamespacesList.GetEntry(i);
+ SvTreeListEntry* pEntry = m_aNamespacesList.GetEntry(i);
::rtl::OUString sPrefix( m_aNamespacesList.GetEntryText( pEntry, 0 ) );
::rtl::OUString sURL( m_aNamespacesList.GetEntryText( pEntry, 1 ) );
diff --git a/svx/source/form/fmexch.cxx b/svx/source/form/fmexch.cxx
index fab396509a3a..4e39878b0502 100644
--- a/svx/source/form/fmexch.cxx
+++ b/svx/source/form/fmexch.cxx
@@ -204,20 +204,20 @@ namespace svxform
}
//--------------------------------------------------------------------
- size_t OControlTransferData::onEntryRemoved( SvLBoxEntry* _pEntry )
+ size_t OControlTransferData::onEntryRemoved( SvTreeListEntry* _pEntry )
{
m_aSelectedEntries.erase( _pEntry );
return m_aSelectedEntries.size();
}
//--------------------------------------------------------------------
- void OControlTransferData::addSelectedEntry( SvLBoxEntry* _pEntry )
+ void OControlTransferData::addSelectedEntry( SvTreeListEntry* _pEntry )
{
m_aSelectedEntries.insert( _pEntry );
}
//--------------------------------------------------------------------
- void OControlTransferData::setFocusEntry( SvLBoxEntry* _pFocusEntry )
+ void OControlTransferData::setFocusEntry( SvTreeListEntry* _pFocusEntry )
{
m_pFocusEntry = _pFocusEntry;
}
@@ -229,7 +229,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- void OControlTransferData::buildPathFormat(SvTreeListBox* pTreeBox, SvLBoxEntry* pRoot)
+ void OControlTransferData::buildPathFormat(SvTreeListBox* pTreeBox, SvTreeListEntry* pRoot)
{
m_aControlPaths.realloc(0);
@@ -246,9 +246,9 @@ namespace svxform
{
// erst mal sammeln wir den Pfad in einem Array ein
::std::vector< sal_uInt32 > aCurrentPath;
- SvLBoxEntry* pCurrentEntry = *loop;
+ SvTreeListEntry* pCurrentEntry = *loop;
- SvLBoxEntry* pLoop = pCurrentEntry;
+ SvTreeListEntry* pLoop = pCurrentEntry;
while (pLoop != pRoot)
{
aCurrentPath.push_back(pLoop->GetChildListPos());
@@ -270,7 +270,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- void OControlTransferData::buildListFromPath(SvTreeListBox* pTreeBox, SvLBoxEntry* pRoot)
+ void OControlTransferData::buildListFromPath(SvTreeListBox* pTreeBox, SvTreeListEntry* pRoot)
{
ListBoxEntrySet aEmpty;
m_aSelectedEntries.swap( aEmpty );
@@ -281,7 +281,7 @@ namespace svxform
{
sal_Int32 nThisPatLength = pPaths[i].getLength();
const sal_uInt32* pThisPath = pPaths[i].getConstArray();
- SvLBoxEntry* pSearch = pRoot;
+ SvTreeListEntry* pSearch = pRoot;
for (sal_Int32 j=0; j<nThisPatLength; ++j)
pSearch = pTreeBox->GetEntry(pSearch, pThisPath[j]);
diff --git a/svx/source/form/tabwin.cxx b/svx/source/form/tabwin.cxx
index accb2c1ed08a..8fa8b73c5c85 100644
--- a/svx/source/form/tabwin.cxx
+++ b/svx/source/form/tabwin.cxx
@@ -161,7 +161,7 @@ sal_Bool FmFieldWinListBox::DoubleClickHdl()
//------------------------------------------------------------------------------
void FmFieldWinListBox::StartDrag( sal_Int8 /*_nAction*/, const Point& /*_rPosPixel*/ )
{
- SvLBoxEntry* pSelected = FirstSelected();
+ SvTreeListEntry* pSelected = FirstSelected();
if (!pSelected)
// no drag without a field
return;
@@ -250,7 +250,7 @@ void FmFieldWin::GetFocus()
//-----------------------------------------------------------------------
sal_Bool FmFieldWin::createSelectionControls( )
{
- SvLBoxEntry* pSelected = pListBox->FirstSelected();
+ SvTreeListEntry* pSelected = pListBox->FirstSelected();
if ( pSelected )
{
// build a descriptor for the currently selected field
diff --git a/svx/source/inc/datanavi.hxx b/svx/source/inc/datanavi.hxx
index 462c9911665e..3949d4c6536a 100644
--- a/svx/source/inc/datanavi.hxx
+++ b/svx/source/inc/datanavi.hxx
@@ -136,7 +136,7 @@ namespace svxform
virtual void StartDrag( sal_Int8 nAction, const Point& rPosPixel );
void DeleteAndClear();
- void RemoveEntry( SvLBoxEntry* _pEntry );
+ void RemoveEntry( SvTreeListEntry* _pEntry );
};
//========================================================================
@@ -163,12 +163,12 @@ namespace svxform
DECL_LINK(TbxSelectHdl, void *);
DECL_LINK(ItemSelectHdl, void *);
- void AddChildren( SvLBoxEntry* _pParent,
+ void AddChildren( SvTreeListEntry* _pParent,
const ImageList& _rImgLst,
const XNode_ref& _xNode );
bool DoToolBoxAction( sal_uInt16 _nToolBoxID );
- SvLBoxEntry* AddEntry( ItemNode* _pNewNode, bool _bIsElement );
- SvLBoxEntry* AddEntry( const XPropertySet_ref& _rPropSet );
+ SvTreeListEntry* AddEntry( ItemNode* _pNewNode, bool _bIsElement );
+ SvTreeListEntry* AddEntry( const XPropertySet_ref& _rPropSet );
void EditEntry( const XPropertySet_ref& _rPropSet );
bool RemoveEntry();
@@ -190,7 +190,7 @@ namespace svxform
bool DoMenuAction( sal_uInt16 _nMenuID );
void EnableMenuItems( Menu* _pMenu );
- inline SvLBoxEntry* GetSelectedItem() const { return m_aItemList.FirstSelected(); }
+ inline SvTreeListEntry* GetSelectedItem() const { return m_aItemList.FirstSelected(); }
inline const String& GetInstanceName() const { return m_sInstanceName; }
inline const String& GetInstanceURL() const { return m_sInstanceURL; }
inline bool GetLinkOnce() const { return m_bLinkOnce; }
diff --git a/svx/source/inc/docrecovery.hxx b/svx/source/inc/docrecovery.hxx
index 12cb6804b1d6..3fcd9ca8ab9e 100644
--- a/svx/source/inc/docrecovery.hxx
+++ b/svx/source/inc/docrecovery.hxx
@@ -571,14 +571,14 @@ class RecovDocListEntry : public SvLBoxString
//---------------------------------------
/** @short TODO */
- RecovDocListEntry( SvLBoxEntry* pEntry,
+ RecovDocListEntry( SvTreeListEntry* pEntry,
sal_uInt16 nFlags,
const String& sText );
//---------------------------------------
/** @short TODO */
virtual void Paint(
- const Point& aPos, SvTreeListBox& aDevice, sal_uInt16 nFlags, SvLBoxEntry* pEntry);
+ const Point& aPos, SvTreeListBox& aDevice, sal_uInt16 nFlags, SvTreeListEntry* pEntry);
};
//===============================================
@@ -611,7 +611,7 @@ class RecovDocList : public SvxSimpleTable
//---------------------------------------
/** @short TODO */
- virtual void InitEntry( SvLBoxEntry* pEntry ,
+ virtual void InitEntry( SvTreeListEntry* pEntry ,
const XubString& sText ,
const Image& aImage1,
const Image& aImage2,
diff --git a/svx/source/inc/filtnav.hxx b/svx/source/inc/filtnav.hxx
index 753b38db21a2..816ed67bdcdf 100644
--- a/svx/source/inc/filtnav.hxx
+++ b/svx/source/inc/filtnav.hxx
@@ -259,7 +259,7 @@ class FmFilterNavigator : public SvTreeListBox, public SfxListener
enum DROP_ACTION{ DA_SCROLLUP, DA_SCROLLDOWN, DA_EXPANDNODE };
FmFilterModel* m_pModel;
- SvLBoxEntry* m_pEditingCurrently;
+ SvTreeListEntry* m_pEditingCurrently;
OFilterExchangeHelper m_aControlExchange;
@@ -284,22 +284,22 @@ protected:
virtual void KeyInput( const KeyEvent& rKEvt );
virtual void Command( const CommandEvent& rEvt );
virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
- virtual void InitEntry(SvLBoxEntry* pEntry, const XubString& rStr, const Image& rImg1, const Image& rImg2, SvLBoxButtonKind eButtonKind);
- virtual sal_Bool Select( SvLBoxEntry* pEntry, sal_Bool bSelect=sal_True );
- virtual sal_Bool EditingEntry( SvLBoxEntry* pEntry, Selection& rSelection );
- virtual sal_Bool EditedEntry( SvLBoxEntry* pEntry, const rtl::OUString& rNewText );
+ virtual void InitEntry(SvTreeListEntry* pEntry, const XubString& rStr, const Image& rImg1, const Image& rImg2, SvLBoxButtonKind eButtonKind);
+ virtual sal_Bool Select( SvTreeListEntry* pEntry, sal_Bool bSelect=sal_True );
+ virtual sal_Bool EditingEntry( SvTreeListEntry* pEntry, Selection& rSelection );
+ virtual sal_Bool EditedEntry( SvTreeListEntry* pEntry, const rtl::OUString& rNewText );
virtual sal_Int8 AcceptDrop( const AcceptDropEvent& rEvt );
virtual sal_Int8 ExecuteDrop( const ExecuteDropEvent& rEvt );
virtual void StartDrag( sal_Int8 nAction, const Point& rPosPixel );
void DeleteSelection();
- SvLBoxEntry* FindEntry(const FmFilterData* pItem) const;
+ SvTreeListEntry* FindEntry(const FmFilterData* pItem) const;
void Insert(FmFilterData* pItem, sal_uLong nPos);
void Remove(FmFilterData* pItem);
- DECL_LINK(OnRemove, SvLBoxEntry*);
- DECL_LINK(OnEdited, SvLBoxEntry*);
+ DECL_LINK(OnRemove, SvTreeListEntry*);
+ DECL_LINK(OnEdited, SvTreeListEntry*);
DECL_LINK(OnDropActionTimer, void*);
private:
@@ -319,8 +319,8 @@ private:
If <TRUE/> the items will not be removed from the model, otherwise they will.
*/
void insertFilterItem(const ::std::vector<FmFilterItem*>& _rFilterList,FmFilterItems* _pTargetItems,sal_Bool _bCopy = sal_False);
- SvLBoxEntry* getPrevEntry(SvLBoxEntry* _pStartWith = NULL);
- SvLBoxEntry* getNextEntry(SvLBoxEntry* _pStartWith = NULL);
+ SvTreeListEntry* getPrevEntry(SvTreeListEntry* _pStartWith = NULL);
+ SvTreeListEntry* getNextEntry(SvTreeListEntry* _pStartWith = NULL);
using SvTreeListBox::Select;
using SvTreeListBox::ExecuteDrop;
diff --git a/svx/source/inc/fmexch.hxx b/svx/source/inc/fmexch.hxx
index 2bafd5652392..3221e644a376 100644
--- a/svx/source/inc/fmexch.hxx
+++ b/svx/source/inc/fmexch.hxx
@@ -27,7 +27,7 @@
#include <svx/svxdllapi.h>
-class SvLBoxEntry;
+class SvTreeListEntry;
//========================================================================
class SvTreeListBox;
@@ -39,7 +39,7 @@ namespace svxform
//====================================================================
- typedef ::std::set< SvLBoxEntry* > ListBoxEntrySet;
+ typedef ::std::set< SvTreeListEntry* > ListBoxEntrySet;
//====================================================================
//= OLocalExchange
@@ -141,7 +141,7 @@ namespace svxform
m_xFormsRoot; // the root of the forms collection where the entries we represent reside
// this uniquely identifies the page and the document
- SvLBoxEntry* m_pFocusEntry;
+ SvTreeListEntry* m_pFocusEntry;
protected:
// updates m_aCurrentFormats with all formats we currently could supply
@@ -157,8 +157,8 @@ namespace svxform
inline const DataFlavorExVector& GetDataFlavorExVector() const;
- void addSelectedEntry( SvLBoxEntry* _pEntry );
- void setFocusEntry( SvLBoxEntry* _pFocusEntry );
+ void addSelectedEntry( SvTreeListEntry* _pEntry );
+ void setFocusEntry( SvTreeListEntry* _pFocusEntry );
/** notifies the data transfer object that a certain entry has been removed from the owning tree
@@ -168,18 +168,18 @@ namespace svxform
@param _pEntry
@return the number of entries remaining in the selection.
*/
- size_t onEntryRemoved( SvLBoxEntry* _pEntry );
+ size_t onEntryRemoved( SvTreeListEntry* _pEntry );
void setFormsRoot(
const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameContainer >& _rxFormsRoot
) { m_xFormsRoot = _rxFormsRoot; }
- void buildPathFormat(SvTreeListBox* pTreeBox, SvLBoxEntry* pRoot);
+ void buildPathFormat(SvTreeListBox* pTreeBox, SvTreeListEntry* pRoot);
// baut aus m_aSelectedEntries m_aControlPaths auf
// (es wird davon ausgegangen, dass die Eintraege in m_aSelectedEntries sortiert sind in Bezug auf die Nachbar-Beziehung)
- void buildListFromPath(SvTreeListBox* pTreeBox, SvLBoxEntry* pRoot);
+ void buildListFromPath(SvTreeListBox* pTreeBox, SvTreeListEntry* pRoot);
// der umgekehrte Weg : wirft alles aus m_aSelectedEntries weg und baut es mittels m_aControlPaths neu auf
void addHiddenControlsFormat(const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > > seqInterfaces);
@@ -187,7 +187,7 @@ namespace svxform
// (es erfolgt KEINE Ueberpruefung, ob dadurch auch tatsaechlich nur hidden Controls bezeichnet werden, dass muss der
// Aufrufer sicherstellen)
- SvLBoxEntry* focused() const { return m_pFocusEntry; }
+ SvTreeListEntry* focused() const { return m_pFocusEntry; }
const ListBoxEntrySet& selected() const { return m_aSelectedEntries; }
::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > >
hiddenControls() const { return m_aHiddenControlModels; }
diff --git a/svx/source/inc/fmexpl.hxx b/svx/source/inc/fmexpl.hxx
index 89a8dd67702b..981fa10e3b80 100644
--- a/svx/source/inc/fmexpl.hxx
+++ b/svx/source/inc/fmexpl.hxx
@@ -417,7 +417,7 @@ namespace svxform
};
//========================================================================
- typedef std::set<SvLBoxEntry*> SvLBoxEntrySortedArray;
+ typedef std::set<SvTreeListEntry*> SvLBoxEntrySortedArray;
class NavigatorTree : public SvTreeListBox, public SfxListener
{
@@ -438,8 +438,8 @@ namespace svxform
::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > m_xORB;
NavigatorTreeModel* m_pNavModel;
- SvLBoxEntry* m_pRootEntry;
- SvLBoxEntry* m_pEditEntry;
+ SvTreeListEntry* m_pRootEntry;
+ SvTreeListEntry* m_pEditEntry;
sal_uLong nEditEvent;
@@ -463,9 +463,9 @@ namespace svxform
void UpdateContent();
- FmControlData* NewControl( const ::rtl::OUString& rServiceName, SvLBoxEntry* pParentEntry, sal_Bool bEditName = sal_True );
- void NewForm( SvLBoxEntry* pParentEntry );
- SvLBoxEntry* Insert( FmEntryData* pEntryData, sal_uLong nRelPos=LIST_APPEND );
+ FmControlData* NewControl( const ::rtl::OUString& rServiceName, SvTreeListEntry* pParentEntry, sal_Bool bEditName = sal_True );
+ void NewForm( SvTreeListEntry* pParentEntry );
+ SvTreeListEntry* Insert( FmEntryData* pEntryData, sal_uLong nRelPos=LIST_APPEND );
void Remove( FmEntryData* pEntryData );
@@ -527,21 +527,21 @@ namespace svxform
void MarkViewObj( FmControlData* pControlData, sal_Bool bMarkHandles, sal_Bool bMark );
void UnmarkAllViewObj();
- sal_Bool IsFormEntry( SvLBoxEntry* pEntry );
- sal_Bool IsFormComponentEntry( SvLBoxEntry* pEntry );
+ sal_Bool IsFormEntry( SvTreeListEntry* pEntry );
+ sal_Bool IsFormComponentEntry( SvTreeListEntry* pEntry );
::rtl::OUString GenerateName( FmEntryData* pEntryData );
NavigatorTreeModel* GetNavModel() const { return m_pNavModel; }
- SvLBoxEntry* FindEntry( FmEntryData* pEntryData );
+ SvTreeListEntry* FindEntry( FmEntryData* pEntryData );
- virtual sal_Bool EditedEntry( SvLBoxEntry* pEntry, const rtl::OUString& rNewText );
- virtual sal_Bool Select( SvLBoxEntry* pEntry, sal_Bool bSelect=sal_True );
- virtual sal_Bool EditingEntry( SvLBoxEntry* pEntry, Selection& );
+ virtual sal_Bool EditedEntry( SvTreeListEntry* pEntry, const rtl::OUString& rNewText );
+ virtual sal_Bool Select( SvTreeListEntry* pEntry, sal_Bool bSelect=sal_True );
+ virtual sal_Bool EditingEntry( SvTreeListEntry* pEntry, Selection& );
virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
virtual void KeyInput( const KeyEvent& rKEvt );
- virtual void ModelHasRemoved( SvListEntry* _pEntry );
+ virtual void ModelHasRemoved( SvTreeListEntry* _pEntry );
using SvTreeListBox::Insert;
using SvTreeListBox::ExecuteDrop;
@@ -550,10 +550,10 @@ namespace svxform
private:
sal_Int8 implAcceptDataTransfer( const DataFlavorExVector& _rFlavors, sal_Int8 _nAction, const Point& _rDropPos, sal_Bool _bDnD );
- sal_Int8 implAcceptDataTransfer( const DataFlavorExVector& _rFlavors, sal_Int8 _nAction, SvLBoxEntry* _pTargetEntry, sal_Bool _bDnD );
+ sal_Int8 implAcceptDataTransfer( const DataFlavorExVector& _rFlavors, sal_Int8 _nAction, SvTreeListEntry* _pTargetEntry, sal_Bool _bDnD );
sal_Int8 implExecuteDataTransfer( const OControlTransferData& _rData, sal_Int8 _nAction, const Point& _rDropPos, sal_Bool _bDnD );
- sal_Int8 implExecuteDataTransfer( const OControlTransferData& _rData, sal_Int8 _nAction, SvLBoxEntry* _pTargetEntry, sal_Bool _bDnD );
+ sal_Int8 implExecuteDataTransfer( const OControlTransferData& _rData, sal_Int8 _nAction, SvTreeListEntry* _pTargetEntry, sal_Bool _bDnD );
// check if a cut, copy, or drag operation can be started in the current situation
sal_Bool implAllowExchange( sal_Int8 _nAction, sal_Bool* _pHasNonHidden = NULL );
diff --git a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
index f58ef9e722c6..41580525a169 100644
--- a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
+++ b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
@@ -207,7 +207,7 @@ void DictionaryList::refillFromDictionary( sal_Int32 nTextConversionOptions )
nConversionPropertyType = xPropertyType->getPropertyType(aLeft, aRight);
DictionaryEntry* pEntry = new DictionaryEntry( aLeft, aRight, nConversionPropertyType );
- SvLBoxEntry* pLBEntry = InsertEntry( makeTabString( *pEntry ) );
+ SvTreeListEntry* pLBEntry = InsertEntry( makeTabString( *pEntry ) );
pLBEntry->SetUserData( pEntry );
}
@@ -232,7 +232,7 @@ DictionaryEntry* DictionaryList::getFirstSelectedEntry() const
DictionaryEntry* DictionaryList::getEntryOnPos( sal_Int32 nPos ) const
{
DictionaryEntry* pEntry=0;
- SvLBoxEntry* pLBEntry = GetEntryOnPos( nPos );
+ SvTreeListEntry* pLBEntry = GetEntryOnPos( nPos );
if(pLBEntry)
pEntry = (DictionaryEntry*)pLBEntry->GetUserData();
return pEntry;
@@ -262,14 +262,14 @@ void DictionaryList::addEntry( const rtl::OUString& rTerm, const rtl::OUString&
return;
DictionaryEntry* pEntry = new DictionaryEntry( rTerm, rMapping, nConversionPropertyType, sal_True );
- SvLBoxEntry* pLBEntry = InsertEntryToColumn( makeTabString( *pEntry ), nPos );
+ SvTreeListEntry* pLBEntry = InsertEntryToColumn( makeTabString( *pEntry ), nPos );
pLBEntry->SetUserData( pEntry );
SelectRow( GetEntryPos( pLBEntry ) );
}
void DictionaryList::deleteEntryOnPos( sal_Int32 nPos )
{
- SvLBoxEntry* pLBEntry = GetEntryOnPos( nPos );
+ SvTreeListEntry* pLBEntry = GetEntryOnPos( nPos );
DictionaryEntry* pEntry = getEntryOnPos( nPos );
if( pLBEntry )
RemoveParentKeepChildren( pLBEntry );
@@ -291,7 +291,7 @@ sal_uIntPtr DictionaryList::deleteEntries( const rtl::OUString& rTerm )
if( rTerm.equals( pCurEntry->m_aTerm ) )
{
nPos = nN;
- SvLBoxEntry* pCurLBEntry = GetEntryOnPos( nN );
+ SvTreeListEntry* pCurLBEntry = GetEntryOnPos( nN );
RemoveParentKeepChildren( pCurLBEntry );
if( pCurEntry->m_bNewEntry )
delete pCurEntry;
@@ -375,12 +375,12 @@ sal_uInt16 DictionaryList::getSortColumn() const
IMPL_LINK( DictionaryList, CompareHdl, SvSortData*, pData )
{
- SvLBoxEntry* pLeft = (SvLBoxEntry*)(pData->pLeft );
- SvLBoxEntry* pRight = (SvLBoxEntry*)(pData->pRight );
+ SvTreeListEntry* pLeft = (SvTreeListEntry*)(pData->pLeft );
+ SvTreeListEntry* pRight = (SvTreeListEntry*)(pData->pRight );
return (long) ColumnCompare(pLeft,pRight);
}
-StringCompare DictionaryList::ColumnCompare( SvLBoxEntry* pLeft, SvLBoxEntry* pRight )
+StringCompare DictionaryList::ColumnCompare( SvTreeListEntry* pLeft, SvTreeListEntry* pRight )
{
StringCompare eCompare=COMPARE_EQUAL;
@@ -408,7 +408,7 @@ StringCompare DictionaryList::ColumnCompare( SvLBoxEntry* pLeft, SvLBoxEntry* pR
return eCompare;
}
-SvLBoxItem* DictionaryList::getItemAtColumn( SvLBoxEntry* pEntry, sal_uInt16 nColumn ) const
+SvLBoxItem* DictionaryList::getItemAtColumn( SvTreeListEntry* pEntry, sal_uInt16 nColumn ) const
{
SvLBoxItem* pItem = NULL;
if( pEntry )
diff --git a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx
index 19709d89afeb..45d76eb2e967 100644
--- a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx
+++ b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.hxx
@@ -109,8 +109,8 @@ private:
String makeTabString( const DictionaryEntry& rEntry ) const;
DECL_LINK( CompareHdl, SvSortData* );
- StringCompare ColumnCompare( SvLBoxEntry* pLeft, SvLBoxEntry* pRight );
- SvLBoxItem* getItemAtColumn( SvLBoxEntry* pEntry, sal_uInt16 nColumn ) const;
+ StringCompare ColumnCompare( SvTreeListEntry* pLeft, SvTreeListEntry* pRight );
+ SvLBoxItem* getItemAtColumn( SvTreeListEntry* pEntry, sal_uInt16 nColumn ) const;
public:
::com::sun::star::uno::Reference<
diff --git a/svx/workben/msview/msview.cxx b/svx/workben/msview/msview.cxx
index 4d35ebaf515b..01a721f516b5 100644
--- a/svx/workben/msview/msview.cxx
+++ b/svx/workben/msview/msview.cxx
@@ -490,13 +490,13 @@ void Atom::compare( Atom* pAtom )
class AtomBoxString : public SvLBoxString
{
public:
- AtomBoxString( SvLBoxEntry* pEntry, const String& rStr )
+ AtomBoxString( SvTreeListEntry* pEntry, const String& rStr )
: SvLBoxString( pEntry, 0, rStr )
{ }
~AtomBoxString() { }
- void Paint( const Point& rPos, SvLBox& rOutDev, USHORT nViewDataEntryFlags, SvLBoxEntry* pEntry )
+ void Paint( const Point& rPos, SvLBox& rOutDev, USHORT nViewDataEntryFlags, SvTreeListEntry* pEntry )
{
Color aOldTextColor = rOutDev.GetTextColor();
@@ -530,16 +530,16 @@ public:
void SetExpandingHdl(const Link& rNewHdl){maExpandingHdl=rNewHdl;}
const Link& GetExpandingHdl() const { return maExpandingHdl; }
- virtual BOOL Expand( SvLBoxEntry* pParent );
- virtual BOOL Collapse( SvLBoxEntry* pParent );
+ virtual BOOL Expand( SvTreeListEntry* pParent );
+ virtual BOOL Collapse( SvTreeListEntry* pParent );
- SvLBoxEntry* findAtom( Atom* pAtom );
+ SvTreeListEntry* findAtom( Atom* pAtom );
- virtual void InitEntry(SvLBoxEntry*,const XubString&,const Image&,const Image&);
+ virtual void InitEntry(SvTreeListEntry*,const XubString&,const Image&,const Image&);
virtual void SetTabs();
private:
- void InsertAtom( const Atom* pAtom, SvLBoxEntry* pParent = 0 );
+ void InsertAtom( const Atom* pAtom, SvTreeListEntry* pParent = 0 );
const Atom* mpRootAtom;
ResMgr* mpResMgr;
Image maImgFolder;
@@ -551,7 +551,7 @@ private:
Link maExpandingHdl;
};
-typedef std::pair< AtomContainerTreeListBox*, SvLBoxEntry* > AtomContainerEntryPair;
+typedef std::pair< AtomContainerTreeListBox*, SvTreeListEntry* > AtomContainerEntryPair;
AtomContainerTreeListBox::AtomContainerTreeListBox( Window* pParent )
: SvTreeListBox( pParent, WB_HASBUTTONS|WB_HASLINES|WB_HASBUTTONSATROOT|WB_3DLOOK|WB_BORDER ),
@@ -591,16 +591,16 @@ void AtomContainerTreeListBox::SetTabs()
AddTab( nStartPos, SV_LBOXTAB_DYNAMIC|SV_LBOXTAB_ADJUST_LEFT | SV_LBOXTAB_SHOW_SELECTION );
}
-void AtomContainerTreeListBox::InitEntry(SvLBoxEntry* pEntry,const XubString& aStr,const Image& aCollEntryBmp,const Image& aExpEntryBmp)
+void AtomContainerTreeListBox::InitEntry(SvTreeListEntry* pEntry,const XubString& aStr,const Image& aCollEntryBmp,const Image& aExpEntryBmp)
{
pEntry->AddItem( new SvLBoxContextBmp( pEntry,0, aCollEntryBmp,aExpEntryBmp, SVLISTENTRYFLAG_EXPANDED ) );
pEntry->AddItem( new SvLBoxContextBmp( pEntry,0, maImgAtom, maImgAtom, SVLISTENTRYFLAG_EXPANDED ) );
pEntry->AddItem( new AtomBoxString( pEntry, aStr ) );
}
-SvLBoxEntry* AtomContainerTreeListBox::findAtom( Atom* pAtom )
+SvTreeListEntry* AtomContainerTreeListBox::findAtom( Atom* pAtom )
{
- SvLBoxEntry* pEntry = First();
+ SvTreeListEntry* pEntry = First();
while( pEntry )
{
if( pEntry->GetUserData() == pAtom )
@@ -612,7 +612,7 @@ SvLBoxEntry* AtomContainerTreeListBox::findAtom( Atom* pAtom )
return 0;
}
-BOOL AtomContainerTreeListBox::Expand( SvLBoxEntry* pParent )
+BOOL AtomContainerTreeListBox::Expand( SvTreeListEntry* pParent )
{
BOOL bRet = FALSE;
if( !mbRecursiveGuard )
@@ -627,7 +627,7 @@ BOOL AtomContainerTreeListBox::Expand( SvLBoxEntry* pParent )
return bRet;
}
-BOOL AtomContainerTreeListBox::Collapse( SvLBoxEntry* pParent )
+BOOL AtomContainerTreeListBox::Collapse( SvTreeListEntry* pParent )
{
BOOL bRet = FALSE;
if( !mbRecursiveGuard )
@@ -648,7 +648,7 @@ void AtomContainerTreeListBox::SetRootAtom( const Atom* pAtom )
InsertAtom( mpRootAtom );
}
-void AtomContainerTreeListBox::InsertAtom( const Atom* pAtom, SvLBoxEntry* pParent /* = 0 */ )
+void AtomContainerTreeListBox::InsertAtom( const Atom* pAtom, SvTreeListEntry* pParent /* = 0 */ )
{
if( pAtom )
{
@@ -671,7 +671,7 @@ void AtomContainerTreeListBox::InsertAtom( const Atom* pAtom, SvLBoxEntry* pPare
sprintf( buffer, " (I: %lu L: %lu)", (UINT32)rHeader.nRecVer, (UINT32)rHeader.nRecLen );
aText += String( rtl::OUString::createFromAscii( buffer ) );
- SvLBoxEntry* pEntry = 0;
+ SvTreeListEntry* pEntry = 0;
if( pAtom->isContainer() && pAtom->findFirstChildAtom() )
{
pEntry = InsertEntry( aText, maImgExpanded, maImgCollapsed, pParent );
@@ -959,7 +959,7 @@ static String GetAtomText( const Atom* pAtom )
IMPL_LINK(MSViewerWorkWindow,implSelectHdl, AtomContainerTreeListBox*, pListBox )
{
int nPane = (pListBox == mpListBox[1]) ? 1 : 0;
- SvLBoxEntry* pEntry = mpListBox[nPane]->FirstSelected();
+ SvTreeListEntry* pEntry = mpListBox[nPane]->FirstSelected();
if( pEntry && pEntry->GetUserData() )
{
Atom* pAtom = static_cast<Atom*>( pEntry->GetUserData() );
@@ -986,7 +986,7 @@ void MSViewerWorkWindow::Sync( AtomContainerEntryPair* pPair, int nAction )
Atom* pAtom = static_cast<Atom*>(pPair->second->GetUserData());
if( pAtom && pAtom->getCompareAtom() )
{
- SvLBoxEntry* pEntry = pDestinationListBox->findAtom( pAtom->getCompareAtom() );
+ SvTreeListEntry* pEntry = pDestinationListBox->findAtom( pAtom->getCompareAtom() );
if(pEntry )
{
@@ -1009,7 +1009,7 @@ void MSViewerWorkWindow::Sync( AtomContainerEntryPair* pPair, int nAction )
IMPL_LINK(MSViewerWorkWindow, implExpandingHdl, AtomContainerEntryPair*, pPair )
{
- SvLBoxEntry* pEntry = pPair->second;
+ SvTreeListEntry* pEntry = pPair->second;
if( pEntry && pEntry->GetUserData() )
{
Atom* pAtom = static_cast<Atom*>( pEntry->GetUserData() );
diff --git a/svx/source/form/filtnav.cxx b/svx/source/form/filtnav.cxx
index 4cde508a406a..7dd1032b9555 100644
--- a/svx/source/form/filtnav.cxx
+++ b/svx/source/form/filtnav.cxx
@@ -873,7 +873,7 @@ void FmFilterModel::Remove( const ::std::vector<FmFilterData*>::iterator& rPos )
FmFilterData* pData = *rPos;
pData->GetParent()->GetChildren().erase( rPos );
// notify the view, this will remove the actual SvLBoxEntry
FmFilterRemovedHint aRemoveHint( pData );
Broadcast( aRemoveHint );
@@ -1038,16 +1038,16 @@ void FmFilterModel::EnsureEmptyFilterRows( FmParentData& _rItem )
class FmFilterItemsString : public SvLBoxString
{
public:
- FmFilterItemsString( SvLBoxEntry* pEntry, sal_uInt16 nFlags, const XubString& rStr )
+ FmFilterItemsString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, const XubString& rStr )
:SvLBoxString(pEntry,nFlags,rStr){}
- virtual void Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvLBoxEntry* pEntry);
- virtual void InitViewData( SvTreeListBox* pView,SvLBoxEntry* pEntry, SvViewDataItem* pViewData);
+ virtual void Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvTreeListEntry* pEntry);
+ virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData);
};
const int nxDBmp = 12;
//------------------------------------------------------------------------
-void FmFilterItemsString::Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 /*nFlags*/, SvLBoxEntry* pEntry )
+void FmFilterItemsString::Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 /*nFlags*/, SvTreeListEntry* pEntry )
{
FmFilterItems* pRow = (FmFilterItems*)pEntry->GetUserData();
FmFormItem* pForm = (FmFormItem*)pRow->GetParent();
@@ -1080,7 +1080,7 @@ void FmFilterItemsString::Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt
}
//------------------------------------------------------------------------
-void FmFilterItemsString::InitViewData( SvTreeListBox* pView,SvLBoxEntry* pEntry, SvViewDataItem* pViewData)
+void FmFilterItemsString::InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData)
{
if( !pViewData )
pViewData = pView->GetViewDataItem( pEntry, this );
@@ -1098,21 +1098,21 @@ class FmFilterString : public SvLBoxString
UniString m_aName;
public:
- FmFilterString( SvLBoxEntry* pEntry, sal_uInt16 nFlags, const XubString& rStr, const UniString& aName)
+ FmFilterString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, const XubString& rStr, const UniString& aName)
:SvLBoxString(pEntry,nFlags,rStr)
,m_aName(aName)
{
m_aName.AppendAscii(": ");
}
- virtual void Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvLBoxEntry* pEntry);
- virtual void InitViewData( SvTreeListBox* pView,SvLBoxEntry* pEntry, SvViewDataItem* pViewData);
+ virtual void Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 nFlags, SvTreeListEntry* pEntry);
+ virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData);
};
const int nxD = 4;
//------------------------------------------------------------------------
-void FmFilterString::InitViewData( SvTreeListBox* pView,SvLBoxEntry* pEntry, SvViewDataItem* pViewData)
+void FmFilterString::InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData)
{
if( !pViewData )
pViewData = pView->GetViewDataItem( pEntry, this );
@@ -1129,7 +1129,7 @@ void FmFilterString::InitViewData( SvTreeListBox* pView,SvLBoxEntry* pEntry, SvV
}
//------------------------------------------------------------------------
-void FmFilterString::Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 /*nFlags*/, SvLBoxEntry* /*pEntry*/ )
+void FmFilterString::Paint(const Point& rPos, SvTreeListBox& rDev, sal_uInt16 /*nFlags*/, SvTreeListEntry* /*pEntry*/ )
{
Font aOldFont( rDev.GetFont());
Font aFont( aOldFont );
@@ -1193,7 +1193,7 @@ void FmFilterNavigator::UpdateContent(const Reference< XIndexAccess > & xControl
m_pModel->Update(xControllers, xCurrent);
// expand the filters for the current controller
- SvLBoxEntry* pEntry = FindEntry(m_pModel->GetCurrentForm());
+ SvTreeListEntry* pEntry = FindEntry(m_pModel->GetCurrentForm());
if (pEntry && !IsExpanded(pEntry))
{
SelectAll(sal_False);
@@ -1212,7 +1212,7 @@ void FmFilterNavigator::UpdateContent(const Reference< XIndexAccess > & xControl
}
//------------------------------------------------------------------------
-sal_Bool FmFilterNavigator::EditingEntry( SvLBoxEntry* pEntry, Selection& rSelection )
+sal_Bool FmFilterNavigator::EditingEntry( SvTreeListEntry* pEntry, Selection& rSelection )
{
m_pEditingCurrently = pEntry;
if (!SvTreeListBox::EditingEntry( pEntry, rSelection ))
@@ -1222,7 +1222,7 @@ sal_Bool FmFilterNavigator::EditingEntry( SvLBoxEntry* pEntry, Selection& rSelec
}
//------------------------------------------------------------------------
-sal_Bool FmFilterNavigator::EditedEntry( SvLBoxEntry* pEntry, const rtl::OUString& rNewText )
+sal_Bool FmFilterNavigator::EditedEntry( SvTreeListEntry* pEntry, const rtl::OUString& rNewText )
{
DBG_ASSERT(pEntry == m_pEditingCurrently, "FmFilterNavigator::EditedEntry: suspicious entry!");
m_pEditingCurrently = NULL;
@@ -1269,7 +1269,7 @@ sal_Bool FmFilterNavigator::EditedEntry( SvLBoxEntry* pEntry, const rtl::OUStrin
}
//------------------------------------------------------------------------
-IMPL_LINK( FmFilterNavigator, OnRemove, SvLBoxEntry*, pEntry )
+IMPL_LINK( FmFilterNavigator, OnRemove, SvTreeListEntry*, pEntry )
{
// now remove the entry
m_pModel->Remove((FmFilterData*) pEntry->GetUserData());
@@ -1294,7 +1294,7 @@ IMPL_LINK_NOARG(FmFilterNavigator, OnDropActionTimer)
break;
case DA_EXPANDNODE:
{
- SvLBoxEntry* pToExpand = GetEntry(m_aTimerTriggered);
+ SvTreeListEntry* pToExpand = GetEntry(m_aTimerTriggered);
if (pToExpand && (GetChildCount(pToExpand) > 0) && !IsExpanded(pToExpand))
// tja, eigentlich muesste ich noch testen, ob die Node nicht schon expandiert ist, aber ich
// habe dazu weder in den Basisklassen noch im Model eine Methode gefunden ...
@@ -1341,7 +1341,7 @@ sal_Int8 FmFilterNavigator::AcceptDrop( const AcceptDropEvent& rEvt )
}
else
{ // is it an entry whith children, and not yet expanded?
- SvLBoxEntry* pDropppedOn = GetEntry(aDropPos);
+ SvTreeListEntry* pDropppedOn = GetEntry(aDropPos);
if (pDropppedOn && (GetChildCount(pDropppedOn) > 0) && !IsExpanded(pDropppedOn))
{
// -> aufklappen
@@ -1379,7 +1379,7 @@ sal_Int8 FmFilterNavigator::AcceptDrop( const AcceptDropEvent& rEvt )
if (!FindEntry(m_aControlExchange->getFormItem()))
return DND_ACTION_NONE;
- SvLBoxEntry* pDropTarget = GetEntry(aDropPos);
+ SvTreeListEntry* pDropTarget = GetEntry(aDropPos);
if (!pDropTarget)
return DND_ACTION_NONE;
@@ -1405,7 +1405,7 @@ sal_Int8 FmFilterNavigator::AcceptDrop( const AcceptDropEvent& rEvt )
// -----------------------------------------------------------------------------
namespace
{
- FmFilterItems* getTargetItems(SvLBoxEntry* _pTarget)
+ FmFilterItems* getTargetItems(SvTreeListEntry* _pTarget)
{
FmFilterData* pData = static_cast<FmFilterData*>(_pTarget->GetUserData());
FmFilterItems* pTargetItems = pData->ISA(FmFilterItems)
@@ -1429,14 +1429,14 @@ sal_Int8 FmFilterNavigator::ExecuteDrop( const ExecuteDropEvent& rEvt )
// das Ziel des Drop sowie einige Daten darueber
Point aDropPos = rEvt.maPosPixel;
- SvLBoxEntry* pDropTarget = GetEntry( aDropPos );
+ SvTreeListEntry* pDropTarget = GetEntry( aDropPos );
if (!pDropTarget)
return DND_ACTION_NONE;
// search the container where to add the items
FmFilterItems* pTargetItems = getTargetItems(pDropTarget);
SelectAll(sal_False);
- SvLBoxEntry* pEntry = FindEntry(pTargetItems);
+ SvTreeListEntry* pEntry = FindEntry(pTargetItems);
Select(pEntry, sal_True);
SetCurEntry(pEntry);
@@ -1446,7 +1446,7 @@ sal_Int8 FmFilterNavigator::ExecuteDrop( const ExecuteDropEvent& rEvt )
}
//------------------------------------------------------------------------
-void FmFilterNavigator::InitEntry(SvLBoxEntry* pEntry,
+void FmFilterNavigator::InitEntry(SvTreeListEntry* pEntry,
const XubString& rStr,
const Image& rImg1,
const Image& rImg2,
@@ -1465,7 +1465,7 @@ void FmFilterNavigator::InitEntry(SvLBoxEntry* pEntry,
}
//------------------------------------------------------------------------
-sal_Bool FmFilterNavigator::Select( SvLBoxEntry* pEntry, sal_Bool bSelect )
+sal_Bool FmFilterNavigator::Select( SvTreeListEntry* pEntry, sal_Bool bSelect )
{
if (bSelect == IsSelected(pEntry)) // das passiert manchmal, ich glaube, die Basisklasse geht zu sehr auf Nummer sicher ;)
return sal_True;
@@ -1519,23 +1519,23 @@ void FmFilterNavigator::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
else if( rHint.ISA(FmFilterTextChangedHint) )
{
FmFilterTextChangedHint* pHint = (FmFilterTextChangedHint*)&rHint;
- SvLBoxEntry* pEntry = FindEntry(pHint->GetData());
+ SvTreeListEntry* pEntry = FindEntry(pHint->GetData());
if (pEntry)
SetEntryText( pEntry, pHint->GetData()->GetText());
}
else if( rHint.ISA(FmFilterCurrentChangedHint) )
{
// invalidate the entries
- for (SvLBoxEntry* pEntry = First(); pEntry != NULL;
+ for (SvTreeListEntry* pEntry = First(); pEntry != NULL;
pEntry = Next(pEntry))
GetModel()->InvalidateEntry( pEntry );
}
}
//------------------------------------------------------------------------
-SvLBoxEntry* FmFilterNavigator::FindEntry(const FmFilterData* pItem) const
+SvTreeListEntry* FmFilterNavigator::FindEntry(const FmFilterData* pItem) const
{
- SvLBoxEntry* pEntry = NULL;
+ SvTreeListEntry* pEntry = NULL;
if (pItem)
{
for (pEntry = First(); pEntry != NULL; pEntry = Next( pEntry ))
@@ -1554,7 +1554,7 @@ void FmFilterNavigator::Insert(FmFilterData* pItem, sal_uLong nPos)
const FmParentData* pParent = pItem->GetParent() ? pItem->GetParent() : GetFilterModel();
// insert the item
- SvLBoxEntry* pParentEntry = FindEntry( pParent );
+ SvTreeListEntry* pParentEntry = FindEntry( pParent );
InsertEntry( pItem->GetText(), pItem->GetImage(), pItem->GetImage(), pParentEntry, sal_False, nPos, pItem );
if ( pParentEntry )
Expand( pParentEntry );
@@ -1564,7 +1564,7 @@ void FmFilterNavigator::Insert(FmFilterData* pItem, sal_uLong nPos)
void FmFilterNavigator::Remove(FmFilterData* pItem)
{
// der Entry zu den Daten
- SvLBoxEntry* pEntry = FindEntry(pItem);
+ SvTreeListEntry* pEntry = FindEntry(pItem);
if (pEntry == m_pEditingCurrently)
// cancel editing
@@ -1581,7 +1581,7 @@ FmFormItem* FmFilterNavigator::getSelectedFilterItems(::std::vector<FmFilterItem
sal_Bool bHandled = sal_True;
sal_Bool bFoundSomething = sal_False;
- for (SvLBoxEntry* pEntry = FirstSelected();
+ for (SvTreeListEntry* pEntry = FirstSelected();
bHandled && pEntry != NULL;
pEntry = NextSelected(pEntry))
{
@@ -1665,7 +1665,7 @@ void FmFilterNavigator::Command( const CommandEvent& rEvt )
{
// die Stelle, an der geklickt wurde
Point aWhere;
- SvLBoxEntry* pClicked = NULL;
+ SvTreeListEntry* pClicked = NULL;
if (rEvt.IsMouseEvent())
{
aWhere = rEvt.GetMousePosPixel();
@@ -1689,7 +1689,7 @@ void FmFilterNavigator::Command( const CommandEvent& rEvt )
}
::std::vector<FmFilterData*> aSelectList;
- for (SvLBoxEntry* pEntry = FirstSelected();
+ for (SvTreeListEntry* pEntry = FirstSelected();
pEntry != NULL;
pEntry = NextSelected(pEntry))
{
@@ -1758,9 +1758,9 @@ void FmFilterNavigator::Command( const CommandEvent& rEvt )
SvTreeListBox::Command( rEvt );
}
// -----------------------------------------------------------------------------
-SvLBoxEntry* FmFilterNavigator::getNextEntry(SvLBoxEntry* _pStartWith)
+SvTreeListEntry* FmFilterNavigator::getNextEntry(SvTreeListEntry* _pStartWith)
{
- SvLBoxEntry* pEntry = _pStartWith ? _pStartWith : LastSelected();
+ SvTreeListEntry* pEntry = _pStartWith ? _pStartWith : LastSelected();
pEntry = Next(pEntry);
// we need the next filter entry
while( pEntry && GetChildCount( pEntry ) == 0 && pEntry != Last() )
@@ -1768,9 +1768,9 @@ SvLBoxEntry* FmFilterNavigator::getNextEntry(SvLBoxEntry* _pStartWith)
return pEntry;
}
// -----------------------------------------------------------------------------
-SvLBoxEntry* FmFilterNavigator::getPrevEntry(SvLBoxEntry* _pStartWith)
+SvTreeListEntry* FmFilterNavigator::getPrevEntry(SvTreeListEntry* _pStartWith)
{
- SvLBoxEntry* pEntry = _pStartWith ? _pStartWith : FirstSelected();
+ SvTreeListEntry* pEntry = _pStartWith ? _pStartWith : FirstSelected();
pEntry = Prev(pEntry);
// check if the previous entry is a filter, if so get the next prev
if ( pEntry && GetChildCount( pEntry ) != 0 )
@@ -1799,11 +1799,11 @@ void FmFilterNavigator::KeyInput(const KeyEvent& rKEvt)
if ( !getSelectedFilterItems( aItemList ) )
break;
- ::std::mem_fun1_t<SvLBoxEntry*,FmFilterNavigator,SvLBoxEntry*> getter = ::std::mem_fun(&FmFilterNavigator::getNextEntry);
+ ::std::mem_fun1_t<SvTreeListEntry*,FmFilterNavigator,SvTreeListEntry*> getter = ::std::mem_fun(&FmFilterNavigator::getNextEntry);
if ( rKeyCode.GetCode() == KEY_UP )
getter = ::std::mem_fun(&FmFilterNavigator::getPrevEntry);
- SvLBoxEntry* pTarget = getter( this, NULL );
+ SvTreeListEntry* pTarget = getter( this, NULL );
if ( !pTarget )
break;
@@ -1871,8 +1871,8 @@ void FmFilterNavigator::DeleteSelection()
{
// to avoid the deletion of an entry twice (e.g. deletion of a parent and afterward
// the deletion of it's child, i have to shrink the selecton list
- ::std::vector<SvLBoxEntry*> aEntryList;
- for (SvLBoxEntry* pEntry = FirstSelected();
+ ::std::vector<SvTreeListEntry*> aEntryList;
+ for (SvTreeListEntry* pEntry = FirstSelected();
pEntry != NULL;
pEntry = NextSelected(pEntry))
{
@@ -1888,7 +1888,7 @@ void FmFilterNavigator::DeleteSelection()
// Remove the selection
SelectAll(sal_False);
- for (::std::vector<SvLBoxEntry*>::reverse_iterator i = aEntryList.rbegin();
+ for (::std::vector<SvTreeListEntry*>::reverse_iterator i = aEntryList.rbegin();
// link problems with operator ==
i.base() != aEntryList.rend().base(); ++i)
{
@@ -873,7 +873,7 @@ void FmFilterModel::Remove( const ::std::vector<FmFilterData*>::iterator& rPos )
FmFilterData* pData = *rPos;
pData->GetParent()->GetChildren().erase( rPos );
- // notify the view, this will remove the actual SvLBoxEntry
+ // notify the view, this will remove the actual SvTreeListEntry
FmFilterRemovedHint aRemoveHint( pData );
Broadcast( aRemoveHint );
diff --git a/svx/source/form/navigatortree.cxx b/svx/source/form/navigatortree.cxx
index c0a151706e28..fe5968f542fd 100644
--- a/svx/source/form/navigatortree.cxx
+++ b/svx/source/form/navigatortree.cxx
@@ -229,7 +229,7 @@ namespace svxform
// wenn es GENAU eine Form gibt, auch diese expandieren
if (m_pRootEntry)
{
- SvLBoxEntry* pFirst = FirstChild(m_pRootEntry);
+ SvTreeListEntry* pFirst = FirstChild(m_pRootEntry);
if (pFirst && !NextSibling(pFirst))
Expand(pFirst);
}
@@ -239,7 +239,7 @@ namespace svxform
sal_Bool NavigatorTree::implAllowExchange( sal_Int8 _nAction, sal_Bool* _pHasNonHidden )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::implAllowExchange" );
- SvLBoxEntry* pCurEntry = GetCurEntry();
+ SvTreeListEntry* pCurEntry = GetCurEntry();
if (!pCurEntry)
return sal_False;
@@ -338,7 +338,7 @@ namespace svxform
if (rEvt.IsMouseEvent())
{
ptWhere = rEvt.GetMousePosPixel();
- SvLBoxEntry* ptClickedOn = GetEntry(ptWhere);
+ SvTreeListEntry* ptClickedOn = GetEntry(ptWhere);
if (ptClickedOn == NULL)
break;
if ( !IsSelected(ptClickedOn) )
@@ -353,7 +353,7 @@ namespace svxform
if (m_arrCurrentSelection.empty()) // kann nur bei Kontextmenue ueber Tastatur passieren
break;
- SvLBoxEntry* pCurrent = GetCurEntry();
+ SvTreeListEntry* pCurrent = GetCurEntry();
if (!pCurrent)
break;
ptWhere = GetEntryPosition(pCurrent);
@@ -500,7 +500,7 @@ namespace svxform
case SID_FM_TAB_DIALOG:
{
// dieser Slot galt bei genau einem selektierten Formular
- SvLBoxEntry* pSelectedForm = *m_arrCurrentSelection.begin();
+ SvTreeListEntry* pSelectedForm = *m_arrCurrentSelection.begin();
DBG_ASSERT( IsFormEntry(pSelectedForm), "NavigatorTree::Command: Dieser Eintrag muss ein FormEntry sein." );
FmFormData* pFormData = (FmFormData*)pSelectedForm->GetUserData();
@@ -554,11 +554,11 @@ namespace svxform
}
//------------------------------------------------------------------------
- SvLBoxEntry* NavigatorTree::FindEntry( FmEntryData* pEntryData )
+ SvTreeListEntry* NavigatorTree::FindEntry( FmEntryData* pEntryData )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::FindEntry" );
if( !pEntryData ) return NULL;
- SvLBoxEntry* pCurEntry = First();
+ SvTreeListEntry* pCurEntry = First();
FmEntryData* pCurEntryData;
while( pCurEntry )
{
@@ -594,7 +594,7 @@ namespace svxform
else if( rHint.ISA(FmNavModelReplacedHint) )
{
FmEntryData* pData = ((FmNavModelReplacedHint*)&rHint)->GetEntryData();
- SvLBoxEntry* pEntry = FindEntry( pData );
+ SvTreeListEntry* pEntry = FindEntry( pData );
if (pEntry)
{ // das Image neu setzen
SetCollapsedEntryBmp( pEntry, pData->GetNormalImage() );
@@ -605,7 +605,7 @@ namespace svxform
else if( rHint.ISA(FmNavNameChangedHint) )
{
FmNavNameChangedHint* pNameChangedHint = (FmNavNameChangedHint*)&rHint;
- SvLBoxEntry* pEntry = FindEntry( pNameChangedHint->GetEntryData() );
+ SvTreeListEntry* pEntry = FindEntry( pNameChangedHint->GetEntryData() );
SetEntryText( pEntry, pNameChangedHint->GetNewName() );
}
@@ -634,13 +634,13 @@ namespace svxform
}
//------------------------------------------------------------------------
- SvLBoxEntry* NavigatorTree::Insert( FmEntryData* pEntryData, sal_uIntPtr nRelPos )
+ SvTreeListEntry* NavigatorTree::Insert( FmEntryData* pEntryData, sal_uIntPtr nRelPos )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::Insert" );
//////////////////////////////////////////////////////////////////////
// Aktuellen Eintrag einfuegen
- SvLBoxEntry* pParentEntry = FindEntry( pEntryData->GetParent() );
- SvLBoxEntry* pNewEntry;
+ SvTreeListEntry* pParentEntry = FindEntry( pEntryData->GetParent() );
+ SvTreeListEntry* pNewEntry;
if( !pParentEntry )
pNewEntry = InsertEntry( pEntryData->GetText(),
@@ -679,7 +679,7 @@ namespace svxform
return;
// der Entry zu den Daten
- SvLBoxEntry* pEntry = FindEntry( pEntryData );
+ SvTreeListEntry* pEntry = FindEntry( pEntryData );
if (!pEntry)
return;
@@ -709,7 +709,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Bool NavigatorTree::IsFormEntry( SvLBoxEntry* pEntry )
+ sal_Bool NavigatorTree::IsFormEntry( SvTreeListEntry* pEntry )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::IsFormEntry" );
FmEntryData* pEntryData = (FmEntryData*)pEntry->GetUserData();
@@ -717,7 +717,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Bool NavigatorTree::IsFormComponentEntry( SvLBoxEntry* pEntry )
+ sal_Bool NavigatorTree::IsFormComponentEntry( SvTreeListEntry* pEntry )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::IsFormComponentEntry" );
FmEntryData* pEntryData = (FmEntryData*)pEntry->GetUserData();
@@ -728,7 +728,7 @@ namespace svxform
sal_Bool NavigatorTree::implAcceptPaste( )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::implAcceptPaste" );
- SvLBoxEntry* pFirstSelected = FirstSelected();
+ SvTreeListEntry* pFirstSelected = FirstSelected();
if ( !pFirstSelected || NextSelected( pFirstSelected ) )
// no selected entry, or at least two selected entries
return sal_False;
@@ -748,7 +748,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Int8 NavigatorTree::implAcceptDataTransfer( const DataFlavorExVector& _rFlavors, sal_Int8 _nAction, SvLBoxEntry* _pTargetEntry, sal_Bool _bDnD )
+ sal_Int8 NavigatorTree::implAcceptDataTransfer( const DataFlavorExVector& _rFlavors, sal_Int8 _nAction, SvTreeListEntry* _pTargetEntry, sal_Bool _bDnD )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::implAcceptDataTransfer" );
// no target -> no drop
@@ -825,7 +825,7 @@ namespace svxform
DBG_ASSERT(aDropped.size() >= 1, "NavigatorTree::implAcceptDataTransfer: keine Eintraege !");
sal_Bool bDropTargetIsComponent = IsFormComponentEntry( _pTargetEntry );
- //SvLBoxEntry* pDropTargetParent = GetParent( _pTargetEntry );
+ //SvTreeListEntry* pDropTargetParent = GetParent( _pTargetEntry );
// conditions to disallow the drop
// 0) the root entry is part of the list (can't DnD the root!)
@@ -838,7 +838,7 @@ namespace svxform
// collect the ancestors of the drop targte (speeds up 3)
SvLBoxEntrySortedArray arrDropAnchestors;
- SvLBoxEntry* pLoop = _pTargetEntry;
+ SvTreeListEntry* pLoop = _pTargetEntry;
while (pLoop)
{
arrDropAnchestors.insert(pLoop);
@@ -850,8 +850,8 @@ namespace svxform
++dropped
)
{
- SvLBoxEntry* pCurrent = *dropped;
- SvLBoxEntry* pCurrentParent = GetParent(pCurrent);
+ SvTreeListEntry* pCurrent = *dropped;
+ SvTreeListEntry* pCurrentParent = GetParent(pCurrent);
// test for 0)
if (pCurrent == m_pRootEntry)
@@ -914,7 +914,7 @@ namespace svxform
bNeedTrigger = sal_True;
} else
{ // auf einem Entry mit Children, der nicht aufgeklappt ist ?
- SvLBoxEntry* pDropppedOn = GetEntry(aDropPos);
+ SvTreeListEntry* pDropppedOn = GetEntry(aDropPos);
if (pDropppedOn && (GetChildCount(pDropppedOn) > 0) && !IsExpanded(pDropppedOn))
{
// -> aufklappen
@@ -950,7 +950,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Int8 NavigatorTree::implExecuteDataTransfer( const OControlTransferData& _rData, sal_Int8 _nAction, SvLBoxEntry* _pTargetEntry, sal_Bool _bDnD )
+ sal_Int8 NavigatorTree::implExecuteDataTransfer( const OControlTransferData& _rData, sal_Int8 _nAction, SvTreeListEntry* _pTargetEntry, sal_Bool _bDnD )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::implExecuteDataTransfer" );
const DataFlavorExVector& rDataFlavors = _rData.GetDataFlavorExVector();
@@ -1035,7 +1035,7 @@ namespace svxform
}
}
- SvLBoxEntry* pToSelect = FindEntry(pNewControlData);
+ SvTreeListEntry* pToSelect = FindEntry(pNewControlData);
Select(pToSelect, sal_True);
if (i == 0)
SetCurEntry(pToSelect);
@@ -1090,7 +1090,7 @@ namespace svxform
)
{
// ein paar Daten zum aktuellen Element
- SvLBoxEntry* pCurrent = *dropped;
+ SvTreeListEntry* pCurrent = *dropped;
DBG_ASSERT(pCurrent != NULL, "NavigatorTree::implExecuteDataTransfer: ungueltiger Eintrag");
DBG_ASSERT(GetParent(pCurrent) != NULL, "NavigatorTree::implExecuteDataTransfer: ungueltiger Eintrag");
// die Root darf nicht gedraggt werden
@@ -1182,10 +1182,10 @@ namespace svxform
GetNavModel()->GetRootList()->insert( pCurrentUserData, nIndex );
// dann bei mir selber bekanntgeben und neu selektieren
- SvLBoxEntry* pNew = Insert( pCurrentUserData, nIndex );
+ SvTreeListEntry* pNew = Insert( pCurrentUserData, nIndex );
if ( ( aDropped.begin() == dropped ) && pNew )
{
- SvLBoxEntry* pParent = GetParent( pNew );
+ SvTreeListEntry* pParent = GetParent( pNew );
if ( pParent )
Expand( pParent );
}
@@ -1269,10 +1269,10 @@ namespace svxform
}
//------------------------------------------------------------------------
- void NavigatorTree::ModelHasRemoved( SvListEntry* _pEntry )
+ void NavigatorTree::ModelHasRemoved( SvTreeListEntry* _pEntry )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::ModelHasRemoved" );
- SvLBoxEntry* pTypedEntry = static_cast< SvLBoxEntry* >( _pEntry );
+ SvTreeListEntry* pTypedEntry = static_cast< SvTreeListEntry* >( _pEntry );
if ( doingKeyboardCut() )
m_aCutEntries.erase( pTypedEntry );
@@ -1301,7 +1301,7 @@ namespace svxform
for ( SvLBoxEntrySortedArray::const_iterator it = m_arrCurrentSelection.begin();
it != m_arrCurrentSelection.end(); ++it )
{
- SvLBoxEntry* pEntry = *it;
+ SvTreeListEntry* pEntry = *it;
if ( pEntry )
{
m_aCutEntries.insert( pEntry );
@@ -1349,7 +1349,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Bool NavigatorTree::EditingEntry( SvLBoxEntry* pEntry, Selection& rSelection )
+ sal_Bool NavigatorTree::EditingEntry( SvTreeListEntry* pEntry, Selection& rSelection )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::EditingEntry" );
if (!SvTreeListBox::EditingEntry( pEntry, rSelection ))
@@ -1360,7 +1360,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- void NavigatorTree::NewForm( SvLBoxEntry* pParentEntry )
+ void NavigatorTree::NewForm( SvTreeListEntry* pParentEntry )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::NewForm" );
//////////////////////////////////////////////////////////////////////
@@ -1417,12 +1417,12 @@ namespace svxform
//////////////////////////////////////////////////////////////////////
// In EditMode schalten
- SvLBoxEntry* pNewEntry = FindEntry( pNewFormData );
+ SvTreeListEntry* pNewEntry = FindEntry( pNewFormData );
EditEntry( pNewEntry );
}
//------------------------------------------------------------------------
- FmControlData* NavigatorTree::NewControl( const ::rtl::OUString& rServiceName, SvLBoxEntry* pParentEntry, sal_Bool bEditName )
+ FmControlData* NavigatorTree::NewControl( const ::rtl::OUString& rServiceName, SvTreeListEntry* pParentEntry, sal_Bool bEditName )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::NewControl" );
//////////////////////////////////////////////////////////////////////
@@ -1462,7 +1462,7 @@ namespace svxform
{
//////////////////////////////////////////////////////////////////////
// In EditMode schalten
- SvLBoxEntry* pNewEntry = FindEntry( pNewFormControlData );
+ SvTreeListEntry* pNewEntry = FindEntry( pNewFormControlData );
Select( pNewEntry, sal_True );
EditEntry( pNewEntry );
}
@@ -1506,7 +1506,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Bool NavigatorTree::EditedEntry( SvLBoxEntry* pEntry, const rtl::OUString& rNewText )
+ sal_Bool NavigatorTree::EditedEntry( SvTreeListEntry* pEntry, const rtl::OUString& rNewText )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::EditedEntry" );
if (EditingCanceled())
@@ -1545,7 +1545,7 @@ namespace svxform
{
case DA_EXPANDNODE:
{
- SvLBoxEntry* pToExpand = GetEntry(m_aTimerTriggered);
+ SvTreeListEntry* pToExpand = GetEntry(m_aTimerTriggered);
if (pToExpand && (GetChildCount(pToExpand) > 0) && !IsExpanded(pToExpand))
// tja, eigentlich muesste ich noch testen, ob die Node nicht schon expandiert ist, aber ich
// habe dazu weder in den Basisklassen noch im Model eine Methode gefunden ...
@@ -1609,7 +1609,7 @@ namespace svxform
++i
)
{
- SvLBoxEntry* pEntry = *i;
+ SvTreeListEntry* pEntry = *i;
if ( !pEntry )
continue;
@@ -1868,7 +1868,7 @@ namespace svxform
m_nFormsSelected = m_nControlsSelected = m_nHiddenControls = 0;
m_bRootSelected = sal_False;
- SvLBoxEntry* pSelectionLoop = FirstSelected();
+ SvTreeListEntry* pSelectionLoop = FirstSelected();
while (pSelectionLoop)
{
// erst mal die Zaehlung der verschiedenen Elemente
@@ -1893,7 +1893,7 @@ namespace svxform
m_arrCurrentSelection.insert(pSelectionLoop);
else
{
- SvLBoxEntry* pParentLoop = GetParent(pSelectionLoop);
+ SvTreeListEntry* pParentLoop = GetParent(pSelectionLoop);
while (pParentLoop)
{
// eigentlich muesste ich testen, ob das Parent in der m_arrCurrentSelection steht ...
@@ -1917,7 +1917,7 @@ namespace svxform
}
else if (sdiHow == SDI_NORMALIZED_FORMARK)
{
- SvLBoxEntry* pParent = GetParent(pSelectionLoop);
+ SvTreeListEntry* pParent = GetParent(pSelectionLoop);
if (!pParent || !IsSelected(pParent) || IsFormEntry(pSelectionLoop))
m_arrCurrentSelection.insert(pSelectionLoop);
}
@@ -1943,7 +1943,7 @@ namespace svxform
else
{
// erst mal gleiche ich meine aktuelle Selektion mit der geforderten SelectList ab
- SvLBoxEntry* pSelection = FirstSelected();
+ SvTreeListEntry* pSelection = FirstSelected();
while (pSelection)
{
FmEntryData* pCurrent = (FmEntryData*)pSelection->GetUserData();
@@ -1969,7 +1969,7 @@ namespace svxform
}
// jetzt habe ich in der SelectList genau die Eintraege, die noch selektiert werden muessen
// zwei Moeglichkeiten : 1) ich gehe durch die SelectList, besorge mir zu jedem Eintrag meinen SvLBoxEntry
// und selektiere diesen (waere irgendwie intuitiver ;)) 2) ich gehe durch alle meine SvLBoxEntries und selektiere
// genau die, die ich in der SelectList finde
// 1) braucht O(k*n) (k=Laenge der SelectList, n=Anzahl meiner Entries), plus den Fakt, dass FindEntry nicht den
@@ -1977,7 +1977,7 @@ namespace svxform
// 2) braucht O(n*log k), dupliziert aber etwas Code (naemlich den aus FindEntry)
// da das hier eine relativ oft aufgerufenen Stelle sein koennte (bei jeder Aenderung in der Markierung in der View !),
// nehme ich doch lieber letzteres
- SvLBoxEntry* pLoop = First();
+ SvTreeListEntry* pLoop = First();
while( pLoop )
{
FmEntryData* pCurEntryData = (FmEntryData*)pLoop->GetUserData();
@@ -2027,7 +2027,7 @@ namespace svxform
for (SvLBoxEntrySortedArray::const_iterator it = m_arrCurrentSelection.begin();
it != m_arrCurrentSelection.end(); ++it)
{
- SvLBoxEntry* pSelectionLoop = *it;
+ SvTreeListEntry* pSelectionLoop = *it;
// Bei Formselektion alle Controls dieser Form markieren
if (IsFormEntry(pSelectionLoop) && (pSelectionLoop != m_pRootEntry))
MarkViewObj((FmFormData*)pSelectionLoop->GetUserData(), sal_True, sal_False);
@@ -2095,7 +2095,7 @@ namespace svxform
}
//------------------------------------------------------------------------
- sal_Bool NavigatorTree::Select( SvLBoxEntry* pEntry, sal_Bool bSelect )
+ sal_Bool NavigatorTree::Select( SvTreeListEntry* pEntry, sal_Bool bSelect )
{
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTree::Select" );
if (bSelect == IsSelected(pEntry)) // das passiert manchmal, ich glaube, die Basisklasse geht zu sehr auf Nummer sicher ;)
@@ -1969,7 +1969,7 @@ namespace svxform
}
// jetzt habe ich in der SelectList genau die Eintraege, die noch selektiert werden muessen
- // zwei Moeglichkeiten : 1) ich gehe durch die SelectList, besorge mir zu jedem Eintrag meinen SvLBoxEntry
+ // zwei Moeglichkeiten : 1) ich gehe durch die SelectList, besorge mir zu jedem Eintrag meinen SvTreeListEntry
// und selektiere diesen (waere irgendwie intuitiver ;)) 2) ich gehe durch alle meine SvLBoxEntries und selektiere
// genau die, die ich in der SelectList finde